@@ -28,26 +28,6 @@ def df_single():
     return X, y
 
 
-@pytest.fixture(scope="module")
-def df_double():
-    # create array with 8 correlated features and 4 independent ones
-    X, y = make_classification(
-        n_samples=1000,
-        n_features=12,
-        n_redundant=4,
-        n_clusters_per_class=1,
-        weights=[0.50],
-        class_sep=2,
-        random_state=1,
-    )
-
-    # transform array into pandas df
-    colnames = ["var_" + str(i) for i in range(12)]
-    X = pd.DataFrame(X, columns=colnames)
-
-    return X, y
-
-
 def test_model_performance_single_corr_group(df_single):
     X, y = df_single
 
@@ -91,8 +71,8 @@ def test_model_performance_single_corr_group(df_single):
     pd.testing.assert_frame_equal(Xt, df)
 
 
-def test_model_performance_2_correlated_groups(df_double):
-    X, y = df_double
+def test_model_performance_2_correlated_groups(df_test):
+    X, y = df_test
 
     transformer = SmartCorrelatedSelection(
         variables=None,
@@ -145,8 +125,8 @@ def test_error_if_select_model_performance_and_y_is_none(df_single):
         transformer.fit(X)
 
 
-def test_variance_2_correlated_groups(df_double):
-    X, y = df_double
+def test_variance_2_correlated_groups(df_test):
+    X, y = df_test
 
     transformer = SmartCorrelatedSelection(
         variables=None,
@@ -174,8 +154,8 @@ def test_variance_2_correlated_groups(df_double):
     pd.testing.assert_frame_equal(Xt, df)
 
 
-def test_cardinality_2_correlated_groups(df_double):
-    X, y = df_double
+def test_cardinality_2_correlated_groups(df_test):
+    X, y = df_test
     X[["var_0", "var_6", "var_7", "var_9"]] = X[
         ["var_0", "var_6", "var_7", "var_9"]
     ].astype(int)
@@ -206,8 +186,8 @@ def test_cardinality_2_correlated_groups(df_double):
     pd.testing.assert_frame_equal(Xt, df)
 
 
-def test_automatic_variable_selection(df_double):
-    X, y = df_double
+def test_automatic_variable_selection(df_test):
+    X, y = df_test
 
     X[["var_0", "var_6", "var_7", "var_9"]] = X[
         ["var_0", "var_6", "var_7", "var_9"]
@@ -255,13 +235,33 @@ def test_automatic_variable_selection(df_double):
     pd.testing.assert_frame_equal(Xt, df)
 
 
+def test_callable_method(df_test, random_uniform_method):
+    X, _ = df_test
+
+    transformer = SmartCorrelatedSelection(
+        variables=None,
+        method=random_uniform_method,
+        threshold=0.8,
+        missing_values="raise",
+        selection_method="variance",
+    )
+
+    Xt = transformer.fit_transform(X)
+
+    # test no empty dataframe
+    assert not Xt.empty
+
+    # test fit attrs
+    assert len(transformer.correlated_feature_sets_) > 0
+    assert len(transformer.features_to_drop_) > 0
+    assert len(transformer.variables_) > 0
+    assert transformer.n_features_in_ == len(X.columns)
+
+
 def test_raises_param_errors():
     with pytest.raises(ValueError):
         SmartCorrelatedSelection(threshold=None)
 
-    with pytest.raises(ValueError):
-        SmartCorrelatedSelection(method="hola")
-
     with pytest.raises(ValueError):
         SmartCorrelatedSelection(missing_values=None)
 
@@ -274,6 +274,31 @@ def test_raises_param_errors():
         )
 
 
+def test_error_method_supplied(df_test):
+
+    X, _ = df_test
+    method = "hola"
+
+    transformer = SmartCorrelatedSelection(
+        variables=None,
+        method=method,
+        threshold=0.8,
+        missing_values="raise",
+        selection_method="variance",
+    )
+
+    with pytest.raises(ValueError) as errmsg:
+        _ = transformer.fit_transform(X)
+
+    exceptionmsg = errmsg.value.args[0]
+
+    assert (
+        exceptionmsg
+        == "method must be either 'pearson', 'spearman', 'kendall', or a callable,"
+        + f" '{method}' was supplied"
+    )
+
+
 def test_error_if_fit_input_not_dataframe():
     with pytest.raises(TypeError):
         SmartCorrelatedSelection().fit({"Name": [1]})
